@@ -59,7 +59,7 @@ def sentiental_analysis_features(data):
 	data['subjectivity']= subjectivities
 	return data
 
-def distribution_sentiment_tweets(data)
+def distribution_sentiment_tweets(data):
 	### VISUALIZATION
 	plt.rcParams['figure.figsize'] = [50, 40]
 	for i in range (len(data)):
@@ -78,9 +78,9 @@ def distribution_sentiment_tweets(data)
 				plt.scatter(x,y, color='purple')
 			else: 
 				plt.scatter(x,y, color='red')  
-    plt.text(x+0.01, y+0.01, 'tweet'+str(i), fontsize=10)
-    plt.xlim(-1,1)
-    plt.ylim(0,1)
+	plt.text(x+0.01, y+0.01, 'tweet'+str(i), fontsize=10)
+	plt.xlim(-1,1)
+	plt.ylim(0,1)
 	plt.title('sentiment anaysis',fontsize=20)
 	plt.xlabel('<------------------ NEGATIVE ------------------   POLARITY ------------------ POSITIVE ------------------>',fontsize=15)
 	plt.ylabel('<----------------- FACTS ------------------ SUBJECTIVITY ------------------ OPINIONS ----------------->',fontsize=15)
@@ -126,7 +126,7 @@ def general_pieChart(data):
 	plt.axis('equal')
 	plt.show()
 	
-def tokenize_tweets(data)
+def tokenize_tweets(data):
 	sample_data_tokenized=[]  
 	tokenizer=RegexpTokenizer(r'\w+')
 	for tweets in data.text:
@@ -145,8 +145,8 @@ def keywords_score(data,sample_data_tokenized, keyword_corpus):
 			scores.append(score/len(sample_data_tokenized[i]))
 		except ZeroDivisionError:
 			scores.append(0)
-    data['keyword_score']=scores
-    return data
+	data['keyword_score']=scores
+	return data
 
 def hashtag_score(data, sample_data_tokenized, hashtag_corpus):
 	scores = []
@@ -254,7 +254,7 @@ def pie_chart_hashtags_terrorist(data):
 			op+=1
 		else:
 			f+=1
-	
+
 	labels = 'Positive', 'Negative','Neutral'
 	sizes = [p,n,o]
 	colors = ['yellowgreen','red', 'gold'] #, 'yellowgreen', 'lightcoral','lightskyblue',
@@ -962,7 +962,7 @@ def NLP_analysis(data, keyword_corpus, hashtag_corpus):
 	tweets_df["terrorist_suggestion"][(tweets_df["terrorist_suggestion"]==1) & (tweets_df["polarity"] < -0.1) & (tweets_df["subjectivity"]>0.6)]= 2
 	data["per_terr_hash_key"] = len(tweets_df[tweets_df["terrorist_suggestion"]==2]) / len(tweets_df[tweets_df["terrorist_suggestion"]==1])
 	data["suggestion"] = "No terrorist"
-	data["suggestion"][((data["per_terr_hash_key"]) >0.7) & (data["per_hash_key"]>0.15))] = "Terrorist"
+	data["suggestion"][((data["per_terr_hash_key"] >0.7) & (data["per_hash_key"]>0.15))] = "Terrorist"
 	
 	return data,tweets_df
 	
